=========================
2018-03-19 SIG Governance
=========================

OpenStack SIGs need a minimal governance structure to make final calls in
case conflicts between SIGs or within the leadership of a given SIG cannot
be solved at the SIG level.

This resolution states that such conflicts should be escalated to the
**SIG admins** group for resolution.

The **SIG admins** group is formed of one User Committee representative and
one Technical Committee representative. In case the two SIG admins disagree
on the resolution of the conflict, the OpenStack Foundation Executive Director
will be asked to break the tie.

NB: the SIG admins group also has +2A rights on the governance-sigs repository
(source of the `SIG governance website`_), and therefore finally approves
new SIG submissions.

.. _SIG governance website: https://governance.openstack.org/sigs/
